@@ -38,6 +38,7 @@ def translate_text(service_account_json_path,
                                  text,
                                  html_or_normal_text=html_or_normal_text)
 
+
 def translate_lines_with_same_context(service_account_json_path,
                                       project_id,
                                       text,
@@ -45,8 +46,10 @@ def translate_lines_with_same_context(service_account_json_path,
                                       language_initials_src='en-US'
                                       ):
     """Will translate a same context text, broken to lines, into a given language.
-    Call this function usually from a screen shot caption or other text of more than one line with the same context. Like:
-    "Use this\nif you want to help\nthe enviorment"
+    Call this function usually from a screenshot caption or other text of more than one line with the same context. Like:
+    "Use this\nif you want to help\nthe environment"
+
+    NOTICE: the program separates new lines using <u> so make sure you aren't using the <u> tag.
 
     Parameters:
         service_account_json_path: the path to your google translate api json key. Download from your firebase's project's settings
